@@ -24,8 +24,8 @@ class FruityWiFiPlugin(PluginBase):
     This plugin handles FruityWiFi clients.
     """
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *arg, **kwargs):
+        super().__init__(*arg, **kwargs)
         self.id = "fruitywifi"
         self.name = "FruityWiFi"
         self.plugin_version = "0.0.1"
@@ -56,18 +56,7 @@ class FruityWiFiPlugin(PluginBase):
             return 5
     
     def createHostInterfaceVuln(self, ip_address, macaddress, hostname, desc, vuln_name, severity):
-        h_id = self.createAndAddHost(ip_address)
-        if self._isIPV4(ip_address):
-            i_id = self.createAndAddInterface(
-                h_id,
-                ip_address,
-                macaddress,
-                ipv4_address=ip_address,
-                hostname_resolution=[hostname]
-                )
-        else:
-            self.createAndAddInterface(
-                h_id, ip_address, ipv6_address=ip_address, hostname_resolution=[hostname])
+        h_id = self.createAndAddHost(ip_address, hostnames=[hostname])
 
         self.createAndAddVulnToHost(
             h_id,
@@ -77,7 +66,7 @@ class FruityWiFiPlugin(PluginBase):
             severity=severity
         )
     
-    def parseOutputString(self, output, debug=False):
+    def parseOutputString(self, output):
         
         try:
             output = json.loads(output)
@@ -138,7 +127,7 @@ class FruityWiFiPlugin(PluginBase):
 
 
 
-def createPlugin():
-    return FruityWiFiPlugin()
+def createPlugin(ignore_info=False):
+    return FruityWiFiPlugin(ignore_info=ignore_info)
+
 
-# I'm Py3
