@@ -68,28 +68,18 @@ class Ip360Plugin(PluginBase):
     Example plugin to parse Ip360 output.
     """
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *arg, **kwargs):
+        super().__init__(*arg, **kwargs)
         self.id = "Ip360"
         self.name = "Ip360 CSV Output Plugin"
         self.plugin_version = "0.0.1"
         self.options = None
 
-    def parseOutputString(self, output, debug=False):
+    def parseOutputString(self, output):
 
         parser = Ip360Parser(output)
         for host, interface, service, vulnerability in parser.parse():
-
-            h_id = self.createAndAddHost(host.get("name"), host.get("os"))
-
-            i_id = self.createAndAddInterface(
-                h_id,
-                interface.get("name"),
-                ipv4_address=interface.get("name"),
-                hostname_resolution=interface.get("hostname_resolution"),
-                network_segment=interface.get("network_segment"))
-
-
+            h_id = self.createAndAddHost(host.get("name"), host.get("os"), hostnames=interface.get("hostname_resolution"))
             if service.get("port") == "-":
                 port = "0"
                 protocol = "unknown"
@@ -97,9 +87,8 @@ class Ip360Plugin(PluginBase):
                 port = service.get("port").split("/")[0]
                 protocol = service.get("port").split("/")[1]
 
-            s_id = self.createAndAddServiceToInterface(
+            s_id = self.createAndAddServiceToHost(
                 h_id,
-                i_id,
                 service.get("port"),
                 protocol=protocol,
                 ports=[port])
@@ -114,7 +103,7 @@ class Ip360Plugin(PluginBase):
                 ref=vulnerability.get("ref"))
 
 
-def createPlugin():
-    return Ip360Plugin()
+def createPlugin(ignore_info=False):
+    return Ip360Plugin(ignore_info=ignore_info)
+
 
-# I'm Py3
